#' @keywords internal
"_PACKAGE"

#' @import JuliaConnectoR
#' @importFrom stats reshape
#' @importFrom utils combn
#' @importFrom magrittr %>%
NULL
